using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.ComponentModel;
using System.Text;

namespace NeoCore.PanelControl {
	/// <summary>
	/// XMSpanelTextBox extends TextBox to create a control usable within the XMSPanelControl
	/// </summary>
	[DefaultProperty("Text"), 
	ToolboxData("<{0}:XMSPanelTextBox runat=server></{0}:XMSPanelTextBox>")]
	public class XMSPanelTextBox : TextBox, XMSControl {
		/// <summary>
		/// The path seperator to use for querys
		/// </summary>
		private static string PATH_SEPARATOR = "/";
	
		/// <summary>
		/// ToXML returns the Xml string this control represents
		/// </summary>
		/// <returns>The xml string</returns>
		public string ToXML() {
			StringBuilder sb = new StringBuilder();
			sb.Append("<");
			sb.Append(this.ID);
			sb.Append(">");
			sb.Append(HttpUtility.HtmlEncode(this.Text));
			sb.Append("</");
			sb.Append(this.ID);
			sb.Append(">");
			return sb.ToString();
		}

		/// <summary>
		/// SetData sets the data for this control
		/// </summary>
		/// <param name="data">The data to set</param>
		public void SetData(string data) {
			this.Text = data;
		}

		/// <summary>
		/// Clear data from the control
		/// </summary>
		public void Clear() {
			this.Text = "";
		}

		/// <summary>
		/// ToXPathPredicate creates a predicate in the form of myName="myValue" and returns that string
		/// </summary>
		/// <param name="prependValue">The which needs to be prepended to the myName to fully represent the path</param>
		/// <returns>The predicate string</returns>
		public string ToXPathPredicate(string prependValue) {
			StringBuilder sb = new StringBuilder();
			if (!this.Text.Equals("")) {
				sb.Append(prependValue);
				sb.Append("/");
				sb.Append(this.ID);
				sb.Append("=\"");
				sb.Append(this.Text);
				sb.Append("\"");
			}
			return sb.ToString();
		}

	}
}
